Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1189)

Unified Diff: media/base/media_log.cc

Issue 1534273002: Switch to standard integer types in media/. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: more Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: media/base/media_log.cc
diff --git a/media/base/media_log.cc b/media/base/media_log.cc
index 754a5f924cee03f1dd8476993660f47165aeb199..d0890c26cb895e3ee6d82a7ec33931e3061d0392 100644
--- a/media/base/media_log.cc
+++ b/media/base/media_log.cc
@@ -216,10 +216,12 @@ scoped_ptr<MediaLogEvent> MediaLog::CreateVideoSizeSetEvent(
}
scoped_ptr<MediaLogEvent> MediaLog::CreateBufferedExtentsChangedEvent(
- int64 start, int64 current, int64 end) {
+ int64_t start,
+ int64_t current,
+ int64_t end) {
scoped_ptr<MediaLogEvent> event(
CreateEvent(MediaLogEvent::BUFFERED_EXTENTS_CHANGED));
// These values are headed to JS where there is no int64 so we use a double
// and accept loss of precision above 2^53 bytes (8 Exabytes).
event->params.SetDouble("buffer_start", start);
event->params.SetDouble("buffer_current", current);
@@ -216,10 +216,12 @@ scoped_ptr<MediaLogEvent> MediaLog::CreateVideoSizeSetEvent(
scoped_ptr<MediaLogEvent> event(
CreateEvent(MediaLogEvent::BUFFERED_EXTENTS_CHANGED));
- // These values are headed to JS where there is no int64 so we use a double
+ // These values are headed to JS where there is no int64_t so we use a double
// and accept loss of precision above 2^53 bytes (8 Exabytes).
event->params.SetDouble("buffer_start", start);
« no previous file with comments | « media/base/media_log.h ('k') | media/base/media_log_event.h » ('j') | media/cdm/stub/stub_cdm.h » ('J')

Powered by Google App Engine
This is Rietveld 408576698